#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_SCALAR_REPEAT_LOWER_HALF_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_SCALAR_REPEAT_LOWER_HALF_HPP_INCLUDED

#include <boost/simd/swar/include/functions/scalar/repeat_lower_half.hpp>

#endif
